@@ -281,6 +281,7 @@ void VNoteMainManager::vNoteCreateFolder()
         data.insert(FOLDER_COUNT_KEY, "0");
         data.insert(FOLDER_ICON_KEY, QString::number(newFolder->defaultIcon));
         data.insert(FOLDER_SORT_KEY, folders->folders.size());
+        data.insert(FOLDER_ID_KEY, newFolder->id);
         addFolderFinished(data);
     } else {
         qWarning() << "Failed to create new folder";
@@ -373,6 +374,7 @@ int VNoteMainManager::loadNotes(VNoteFolder *folder)
         VNoteItemOper noteOper;
         VNOTE_ITEMS_MAP *notes = noteOper.getFolderNotes(folder->id);
         QList<QVariantMap> notesDataList;
+        const int preferredNoteId = m_currentNoteId;
         if (notes) {
             qInfo() << "notes is not nullptr";
             notes->lock.lockForRead();
@@ -396,13 +398,29 @@ int VNoteMainManager::loadNotes(VNoteFolder *folder)
 
             std::sort(notesDataList.begin(), notesDataList.end(), NoteCompare());
         }
+        int selectIndex = 0;
         if (!notesDataList.isEmpty()) {
             qInfo() << "notesDataList is not empty";
-            m_currentNoteId = notesDataList.first().value("noteId").toInt();
-            vNoteChanged(m_currentNoteId);
-        } else
+            bool foundPreferredNote = false;
+            if (preferredNoteId > 0) {
+                for (int i = 0; i < notesDataList.size(); ++i) {
+                    if (notesDataList[i].value("noteId").toInt() == preferredNoteId) {
+                        selectIndex = i;
+                        foundPreferredNote = true;
+                        break;
+                    }
+                }
+            }
+            if (!foundPreferredNote) {
+                selectIndex = 0;
+                m_currentNoteId = notesDataList[selectIndex].value("noteId").toInt();
+                vNoteChanged(m_currentNoteId);
+                qDebug() << "Switched to note ID:" << m_currentNoteId << "at index:" << selectIndex;
+            }
+        } else {
             m_currentNoteId = -1;
-        emit updateNotes(notesDataList, 0);
+        }
+        emit updateNotes(notesDataList, selectIndex);
     }
     qInfo() << "Notes loading finished, count:" << notesCount;
     return notesCount;
@@ -811,7 +829,7 @@ void VNoteMainManager::renameNote(const int &index, const QString &newName)
         if (noteOps.modifyNoteTitle(newName)) {
             qDebug() << "Note renamed successfully";
             // 播放中不重新加载列表，避免中断播放状态
-            if (!OpsStateInterface::instance()->isPlaying()) {
+            if (!OpsStateInterface::instance()->isPlaying() && !isInSearchMode()) {
                 qDebug() << "Not playing, reloading current folder";
                 VNoteFolder *currentFolder = getFloderById(m_currentFolderIndex);
                 if (currentFolder) {
@@ -965,16 +983,18 @@ void VNoteMainManager::insertImages(const QList<QUrl> &filePaths)
 void VNoteMainManager::checkNoteVoice(const QVariantList &index)
 {
     qInfo() << "Checking note voice for" << index.size() << "notes";
+    bool hasVoice = false;
     foreach (auto id, index) {
         int noteIndex = id.toInt();
         VNoteItem *item = getNoteById(noteIndex);
         if (item->haveVoice()) {
-            ActionManager::instance()->enableAction(ActionManager::NoteSaveVoice, true);
-            return;
+            hasVoice = true;
+            break;
         }
     }
-    ActionManager::instance()->enableAction(ActionManager::NoteSaveVoice, false);
-    qInfo() << "Note voice check finished";
+    ActionManager::instance()->enableAction(ActionManager::NoteSaveVoice, hasVoice);
+    emit saveVoiceStateChanged(hasVoice);
+    qInfo() << "Note voice check finished, hasVoice:" << hasVoice;
 }
 
 void VNoteMainManager::checkNoteText(const QVariantList &index)
@@ -998,9 +1018,11 @@ void VNoteMainManager::checkNoteText(const QVariantList &index)
 
 void VNoteMainManager::clearSearch()
 {
-    // qInfo() << "Clearing search";
+    qInfo() << "Clearing search";
     m_searchText = "";
-    // qInfo() << "Search cleared";
+    // 发出信号清除搜索高亮
+    emit updateRichTextSearch("");
+    qInfo() << "Search cleared";
 }
 
 bool VNoteMainManager::isInSearchMode() const
