@@ -27,12 +27,28 @@
 #include <QTextDocumentFragment>
 #include <QDBusInterface>
 #include <QDBusConnection>
+#include <QDir>
+#include <QStandardPaths>
 
 Utils::Utils()
 {
     qInfo() << "Utils constructor called";
 }
 
+QString Utils::makeVoiceAbsolute(const QString &voicePath)
+{
+    const QUrl url(voicePath);
+    if (url.isValid() && !url.scheme().isEmpty())
+        return voicePath;
+    const QString vNative = QDir::toNativeSeparators(voicePath);
+    if (QDir::isAbsolutePath(vNative))
+        return vNative;
+    const QString appData = QDir::toNativeSeparators(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
+    if (appData.isEmpty())
+        return voicePath;
+    return QDir::toNativeSeparators(QDir::cleanPath(appData + QDir::separator() + vNative));
+}
+
 /**
  * @brief Utils::convertDateTime
  * @param dateTime 时间
@@ -546,3 +562,16 @@ bool Utils::isCommunityEdition()
 {
     return uosEditionType() == DSysInfo::UosEdition::UosCommunity;
 }
+
+QString Utils::makeVoiceRelative(const QString &voicePath)
+{
+    const QString appData = QDir::toNativeSeparators(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
+    if (appData.isEmpty())
+        return voicePath;
+    const QString v = QDir::toNativeSeparators(voicePath);
+    const QString voiceRoot = QDir::toNativeSeparators(QDir::cleanPath(QDir(appData).filePath(QStringLiteral("voicenote"))));
+    const QString voiceRootWithSep = voiceRoot.endsWith(QDir::separator()) ? voiceRoot : voiceRoot + QDir::separator();
+    if (v.startsWith(voiceRootWithSep))
+        return QStringLiteral("voicenote/") + v.mid(voiceRootWithSep.size());
+    return voicePath;
+}
