@@ -6,9 +6,11 @@
 
 #include <QFile>
 #include <QDir>
+#include <QStandardPaths>
 #include <QLibraryInfo>
 #include <QLibrary>
 #include <QDebug>
+#include <QUrl>
 
 #include "vnoteitem.h"
 #include "common/vlcplayer.h"
@@ -60,6 +62,10 @@ void VoicePlayerHandler::playVoice(const QVariant &json, bool bIsSame)
         m_voiceBlock = QSharedPointer<VNVoiceBlock>::create();
         MetaDataParser parser;
         parser.parse(json, m_voiceBlock.get());
+        // 展开相对路径为绝对路径，便于实际播放
+        if (m_voiceBlock && !m_voiceBlock->voicePath.isEmpty()) {
+            m_voiceBlock->voicePath = Utils::makeVoiceAbsolute(m_voiceBlock->voicePath);
+        }
     }
 
     if (!QFile::exists(m_voiceBlock->voicePath)) {
