@@ -10,8 +10,10 @@
 #include "vtextspeechandtrmanager.h"
 #include "voice_player_handler.h"
 #include "voice_to_text_handler.h"
+#include "voice_recoder_handler.h"
 #include "setting.h"
 #include "globaldef.h"
+#include "common/utils.h"
 
 #include <QApplication>
 #include <QCursor>
@@ -59,6 +61,7 @@ const QString DEEPIN_DAEMON_APPEARANCE_SERVICE = isV20() ? APPEARANCE_SERVICE_V2
 const QString DEEPIN_DAEMON_APPEARANCE_PATH = isV20() ? APPEARANCE_PATH_V20 : APPEARANCE_PATH_V23;
 const QString DEEPIN_DAEMON_APPEARANCE_INTERFACE = isV20() ? APPEARANCE_INTERFACE_V20 : APPEARANCE_INTERFACE_V23;
 
+
 DGUI_USE_NAMESPACE
 
 /*!
@@ -93,6 +96,17 @@ WebEngineHandler::WebEngineHandler(QObject *parent)
             Q_EMIT playingVoice(true);
         }
     });
+    
+    // 监听录音状态变化，控制编辑器中语音播放按钮的启用/禁用
+    connect(VoiceRecoderHandler::instance(), &VoiceRecoderHandler::recoderStateChange, this, 
+            [](VoiceRecoderHandler::RecoderType type) {
+        qInfo() << "WebEngineHandler: Recording state changed to:" << type;
+        // 录音时禁用播放按钮，非录音时启用
+        bool enablePlayButton = (type != VoiceRecoderHandler::Recording);
+        qInfo() << "WebEngineHandler: Setting voice play button enable to:" << enablePlayButton;
+        Q_EMIT JsContent::instance()->callJsSetVoicePlayBtnEnable(enablePlayButton);
+    });
+    
     qInfo() << "WebEngineHandler constructor finished";
 }
 
@@ -279,13 +293,15 @@ void WebEngineHandler::onContextMenuRequested(QWebEngineContextMenuRequest *requ
 /**
    @brief 插入音频文件， \a voicePath 为音频文件路径， \a voiceSize 为音频的长度，单位 ms
  */
+
 void WebEngineHandler::onInsertVoiceItem(const QString &voicePath, quint64 voiceSize)
 {
     qDebug() << "Inserting voice item, path:" << voicePath << "size:" << voiceSize << "ms";
 
     VNVoiceBlock data;
     data.ptrVoice->voiceSize = voiceSize;
-    data.ptrVoice->voicePath = voicePath;
+    // 存储相对路径：AppData/voicenote/ -> voicenote/...
+    data.ptrVoice->voicePath = Utils::makeVoiceRelative(voicePath);
     data.ptrVoice->createTime = QDateTime::currentDateTime();
     data.ptrVoice->voiceTitle = data.ptrVoice->createTime.toString("yyyyMMdd hh.mm.ss");
 
@@ -361,19 +377,31 @@ void WebEngineHandler::onMenuClicked(ActionManager::ActionKind kind)
         case ActionManager::PictureSelectAll:
         case ActionManager::TxtSelectAll:
             // 模拟全选快捷键ctrl+A
+#ifdef USE_QT5
+            Q_EMIT triggerWebAction((int)QWebEnginePage::SelectAll);
+#else
             Q_EMIT triggerWebAction(QWebEnginePage::SelectAll);
+#endif
             break;
         case ActionManager::VoiceCopy:
         case ActionManager::PictureCopy:
         case ActionManager::TxtCopy:
             // 直接调用web端的复制事件
+#ifdef USE_QT5
+            Q_EMIT triggerWebAction((int)QWebEnginePage::Copy);
+#else
             Q_EMIT triggerWebAction(QWebEnginePage::Copy);
+#endif
             break;
         case ActionManager::VoiceCut:
         case ActionManager::PictureCut:
         case ActionManager::TxtCut:
             // 直接调用web端的剪切事件
+#ifdef USE_QT5
+            Q_EMIT triggerWebAction((int)QWebEnginePage::Cut);
+#else
             Q_EMIT triggerWebAction(QWebEnginePage::Cut);
+#endif
             break;
         case ActionManager::VoicePaste:
         case ActionManager::PicturePaste:
@@ -460,13 +488,18 @@ void WebEngineHandler::onPaste(bool isVoice)
     qDebug() << "Paste operation requested, isVoice:" << isVoice;
     if (isVoice) {
         qInfo() << "Paste operation requested, isVoice is true";
+#ifdef USE_QT5
+        Q_EMIT triggerWebAction((int)QWebEnginePage::Paste);
+#else
         Q_EMIT triggerWebAction(QWebEnginePage::Paste);
+#endif
         return;
     }
 
     // 获取剪贴板信息
     QClipboard *clipboard = QApplication::clipboard();
     const QMimeData *mimeData = clipboard->mimeData();
+    
     // 存在文件url
     if (mimeData->hasUrls()) {
         qInfo() << "mimeData has urls";
@@ -482,7 +515,11 @@ void WebEngineHandler::onPaste(bool isVoice)
     } else {
         // 无图片文件，直接调用web端的粘贴事件
         qDebug() << "Pasting text content";
+#ifdef USE_QT5
+        Q_EMIT triggerWebAction((int)QWebEnginePage::Paste);
+#else
         Q_EMIT triggerWebAction(QWebEnginePage::Paste);
+#endif
     }
     qInfo() << "Paste operation finished";
 }
@@ -501,8 +538,13 @@ void WebEngineHandler::processVoiceMenuRequest(QObject *request)
         return;
     }
 
+    // 展开相对路径为绝对路径，避免误判
+    if (m_voiceBlock && !m_voiceBlock->voicePath.isEmpty()) {
+        m_voiceBlock->voicePath = Utils::makeVoiceAbsolute(m_voiceBlock->voicePath);
+    }
+
     // 语音文件不存在使用弹出提示
-    if (!QFile(m_voiceBlock->voicePath).exists()) {
+    if (!QFile::exists(m_voiceBlock->voicePath)) {
         // 异步操作，防止阻塞前端事件
         QTimer::singleShot(0, this, [this] {
             Q_EMIT requestMessageDialog(VNoteMessageDialogHandler::VoicePathNoAvail);
@@ -531,8 +573,13 @@ void WebEngineHandler::processVoiceMenuRequest(QWebEngineContextMenuRequest *req
         return;
     }
 
+    // 展开相对路径为绝对路径，避免误判
+    if (m_voiceBlock && !m_voiceBlock->voicePath.isEmpty()) {
+        m_voiceBlock->voicePath = Utils::makeVoiceAbsolute(m_voiceBlock->voicePath);
+    }
+
     // 语音文件不存在使用弹出提示
-    if (!QFile(m_voiceBlock->voicePath).exists()) {
+    if (!QFile::exists(m_voiceBlock->voicePath)) {
         qInfo() << "Voice file does not exist";
         // 异步操作，防止阻塞前端事件
         QTimer::singleShot(0, this, [this] {
@@ -728,8 +775,22 @@ bool WebEngineHandler::saveMP3()
         setting::instance()->setOption(VNOTE_EXPORT_TEXT_PATH_KEY, dir.path());
         qDebug() << "Saved unified export path to settings:" << dir.path();
         
+        // 如果目标文件已存在，先删除它（因为 QFile::copy 不会覆盖已存在的文件）
+        // 用户已经在 getSaveFileName 对话框中确认覆盖
+        if (QFile::exists(fileName)) {
+            qDebug() << "Target file exists, removing it before copy:" << fileName;
+            if (!QFile::remove(fileName)) {
+                qWarning() << "Failed to remove existing file:" << fileName;
+                return false;
+            }
+        }
+        
         QFile tmpFile(m_voiceBlock.get()->voicePath);
-        return tmpFile.copy(fileName);
+        bool copyResult = tmpFile.copy(fileName);
+        if (!copyResult) {
+            qWarning() << "Failed to copy voice file from:" << m_voiceBlock.get()->voicePath << "to:" << fileName;
+        }
+        return copyResult;
     }
     qInfo() << "MP3 saving finished, result is true";
     return true;
