@@ -119,7 +119,7 @@ var nodeTplV2 = `
     </div>`;
 
 var h5TplV2 = `
-    <div class="li voiceBox" contenteditable="false" draggable="true" jsonKey="{{jsonValue}}">
+    <div class="li voiceBox" draggable="true" jsonKey="{{jsonValue}}">
         ${nodeTplV2}
     </div>
     {{#if text}}
@@ -139,9 +139,12 @@ var isVoicePaste = false
 var isShowAir = true
 var nowClickVoice = null
 var global_activeColor = ''
+var lastRightClickX = 0;  // 保存右键点击的X坐标
+var lastRightClickY = 0;  // 保存右键点击的Y坐标
 var global_disableColor = ''
 var global_theme = 1    // theme type 1:light 2:dark
 var global_themeColor = 'transparent'  //主题色
+var global_isRecording = false  // 录音状态标志
 var scrollHide = null  //滚动条隐藏定时器
 var scrollHideFont = null  //字体滚动条定时
 var isUlOrOl = false
@@ -201,10 +204,28 @@ function setInitFont(initFontName) {
     $('body').css('font-family', initFontName)
 }
 
+// 全局变量：存储 AppData 基准路径，仅用于编辑区内图片/音频路径转换
+var globalAppDataBase = null;
+
 // 建立通信
 new QWebChannel(qt.webChannelTransport,
     function (channel) {
         webobj = channel.objects.webobj;
+        // 获取 AppData 路径，用于编辑区内资源路径转换
+        if (webobj && webobj.jsCallGetAppDataPath) {
+            webobj.jsCallGetAppDataPath(function (res) {
+                try {
+                    if (res && typeof res === 'string') {
+                        globalAppDataBase = ('' + res).replace(/\\+/g, '/');
+                        if (globalAppDataBase.length > 0 && globalAppDataBase[globalAppDataBase.length - 1] !== '/') {
+                            globalAppDataBase += '/';
+                        }
+                    }
+                } catch (e) {
+                    console.error('get AppData path failed:', e);
+                }
+            });
+        }
         //所有的c++ 调用js的接口都需要在此绑定格式，webobj.c++函数名（jscontent.cpp查看.connect(js处理函数)
         //例如 webobj.c++fun.connect(jsfun)
         webobj.callJsInitData.connect(initData);
@@ -313,6 +334,18 @@ function changeContent(we, contents, $editable) {
                 $('#summernote').summernote('airPopover.hide')
             }
         }
+        // 清理撤销后可能残留的临时CSS状态类
+        // summernote的undo可能恢复了包含'now'、'play'等临时状态的HTML
+        $('.voicePlayback').each(function() {
+            var $playback = $(this);           
+            if (activePlayback === null || 
+                !activePlayback.length || 
+                !$playback.is(activePlayback) ||
+                !$.contains(document.documentElement, activePlayback[0])) {
+                $playback.removeClass('now').removeClass('play').removeClass('pause');
+            }
+        });
+        
         webobj.jsCallTxtChange();
     }
 }
@@ -348,6 +381,11 @@ function isNoteNull() {
 
 //点击选中录音
 $('body').on('click', '.li', function (e) {
+    // 如果点击的是 translateText，不选中语音块，让用户选择文本
+    if ($(e.target).closest('.translateText').length > 0) {
+        return;
+    }
+    
     e.stopPropagation();
     $('.li').removeClass('active');
     setSelectRange(this)
@@ -360,6 +398,45 @@ $('body').on('click', '.translate', function (e) {
     e.stopPropagation();
 })
 
+// voiceBox 和 translateText 阻止编辑但允许选择
+$('body').on('keydown keypress input', '.voiceBox, .translateText', function (e) {
+    // 只允许选择和复制，阻止所有编辑
+    if ((e.ctrlKey || e.metaKey) && (e.keyCode === 67 || e.keyCode === 65)) {
+        // Ctrl+C / Ctrl+A 允许
+        return true;
+    }
+    e.preventDefault();
+    return false;
+})
+
+$('body').on('paste drop', '.voiceBox, .translateText', function (e) {
+    e.preventDefault();
+    return false;
+})
+
+// translateText 的鼠标和拖拽事件：禁止拖拽整个 voiceBox，允许文本选择
+$('body').on('mousedown', '.translateText', function (e) {
+    // 阻止冒泡到 .li，避免选中整个语音块
+    e.stopPropagation();
+    
+    // 临时禁用父元素的 draggable 属性，让文本可以被选择
+    var $voiceBox = $(this).closest('.voiceBox');
+    $voiceBox.attr('draggable', 'false');
+})
+
+// 鼠标释放时恢复 draggable
+$('body').on('mouseup', '.translateText', function (e) {
+    var $voiceBox = $(this).closest('.voiceBox');
+    $voiceBox.attr('draggable', 'true');
+})
+
+// 阻止 translateText 触发 dragstart（防止拖拽整个语音块）
+$('body').on('dragstart', '.translateText', function (e) {
+    e.preventDefault();
+    e.stopPropagation();
+    return false;
+})
+
 /**
  * 获取选区
  * @date 2021-09-08
@@ -426,8 +503,24 @@ function removeSelectRange(dom) {
 }
 
 // 取消选中样式
-$('body').on('click', function () {
+$('body').on('click', function (e) {
     $('.li').removeClass('active');
+    if ($(e.target).closest('.voiceBox').length == 0 && 
+        $(e.target).closest('.voicePlayback').length == 0 &&
+        !$(e.target).hasClass('demo') && 
+        $(e.target).parents('.demo').length == 0) {
+        try {
+            var sel = window.getSelection();
+            if (sel.rangeCount > 0) {
+                var range = sel.getRangeAt(0);
+                var fragment = range.cloneContents();
+                if ($(fragment).find('.voiceBox').length > 0) {
+                    sel.removeAllRanges();
+                }
+            }
+        } catch (e) {
+        }
+    }
 })
 
 // 语音复制
@@ -576,6 +669,12 @@ function isRangeVoice() {
  * 播放按钮点击时触发
  */
 $('body').on('click', '.voiceBtn', function (e) {
+    // 录音时禁止播放语音
+    if (global_isRecording) {
+        console.log("Cannot play voice while recording");
+        return;
+    }
+    
     var curPlayback = $(this).parents('.voicePlayback:first');
     // 点击浮动窗口时视同点击焦点音频播放控件
     if (curPlayback.is(airVoicePlayback)) {
@@ -584,6 +683,14 @@ $('body').on('click', '.voiceBtn', function (e) {
     var curVoice = $(this).parents('.li:first');
     var jsonString = curVoice.attr('jsonKey');
     var bIsSame = curPlayback.hasClass('now');
+    var isActivePlaybackValid = (null !== activePlayback && 
+                                  activePlayback.length > 0 && 
+                                  $.contains(document.documentElement, activePlayback[0]));
+    
+    if (!isActivePlaybackValid && activePlayback !== null) {
+        activePlayback = null;
+        bIsSame = false; 
+    }
 
     // 不同，更新当前播放控件；暂停设置等待后端处理完成后 -> callJsSetPlayStatus()
     if (!bIsSame) {
@@ -593,7 +700,6 @@ $('body').on('click', '.voiceBtn', function (e) {
         }
         curPlayback.addClass('now');
         activePlayback = curPlayback;
-
         // 重置悬浮工具栏状态
         resetAirVoicePlayback();
     }
@@ -617,6 +723,49 @@ function getHtml() {
     $cloneCode.find('.voiceInfoBox').removeClass('containText');
     // 移除悬浮工具栏
     $cloneCode.find('.airVoicePlayback').removeClass('active').html("");
+    
+    // 确保图片保存为相对路径
+    $cloneCode.find('img').each(function () {
+        var $img = $(this);
+        var relPath = $img.attr('data-rel-path');
+        if (relPath) {
+            $img.attr('src', relPath);
+            $img.removeAttr('data-rel-path');
+        } else {
+            // 如果没有 data-rel-path，尝试从当前 src 提取相对路径
+            var src = $img.attr('src') || '';
+            if (src.indexOf('images/') >= 0) {
+                var idx = src.lastIndexOf('images/');
+                if (idx >= 0) {
+                    $img.attr('src', src.substring(idx));
+                }
+            }
+        }
+    });
+    
+    // 确保音频 JSON 中 voicePath 保存为相对路径
+    $cloneCode.find('.voiceBox[jsonKey]').each(function () {
+        try {
+            var jsonStr = $(this).attr('jsonKey');
+            if (!jsonStr) return;
+            var json = JSON.parse(jsonStr);
+            if (json.voicePath) {
+                // 如果是绝对路径，转换为相对路径
+                var vp = json.voicePath.replace(/\\/g, '/');
+                if (vp.indexOf('voicenote/') >= 0) {
+                    var idx = vp.lastIndexOf('voicenote/');
+                    json.voicePath = vp.substring(idx);
+                } else if (vp.indexOf('/voicenote/') >= 0) {
+                    var idx = vp.lastIndexOf('/voicenote/');
+                    json.voicePath = 'voicenote/' + vp.substring(idx + '/voicenote/'.length);
+                }
+                $(this).attr('jsonKey', JSON.stringify(json));
+            }
+        } catch (e) {
+            console.error('process voice jsonKey failed:', e);
+        }
+    });
+    
     return $cloneCode[0].innerHTML;
 }
 
@@ -745,6 +894,10 @@ function initData(text) {
  * @returns {any}
  */
 function playButColor(status) {
+    // 更新录音状态（启用时不录音，禁用时在录音）
+    global_isRecording = !status;
+    console.log("playButColor: status=" + status + ", global_isRecording=" + global_isRecording);
+    
     if (!status) {
         setVoiceButColor(global_disableColor, global_disableColor)
 
@@ -815,6 +968,10 @@ function updatePlayBackState(playback, state) {
         return;
     }
 
+    if (playback.length === 0 || !$.contains(document.documentElement, playback[0])) {
+        return;
+    }
+
     if (state == '0') {
         playback.removeClass('pause');
         playback.addClass('play');
@@ -823,6 +980,9 @@ function updatePlayBackState(playback, state) {
     } else {
         // 重置状态
         var progressBar = playback.find('.progressBar').get(0);
+        if (!progressBar) {
+            return;
+        }
         progressBar.value = 0;
         updateProgressBarValue(progressBar, progressBar.value);
 
@@ -859,6 +1019,25 @@ function setHtml(html) {
     initFinish = false;
     $('#summernote').summernote('code', html);
 
+    // 将图片相对路径转换为绝对路径用于显示（仅处理编辑区内的资源）
+    if (globalAppDataBase) {
+        $('.note-editable img').each(function () {
+            var $img = $(this);
+            var src = $img.attr('src') || '';
+            // 如果是相对路径 images/xxx，转换为绝对路径显示
+            if (src.indexOf('images/') === 0 || (src.indexOf('/images/') > 0 && !src.startsWith('file://') && !src.startsWith('http'))) {
+                var relPath = src.indexOf('images/') >= 0 ? src.substring(src.lastIndexOf('images/')) : src;
+                try {
+                    var absUrl = new URL(relPath, globalAppDataBase).href;
+                    $img.attr('src', absUrl);
+                    $img.attr('data-rel-path', relPath);
+                } catch (e) {
+                    // 转换失败，保持原样
+                }
+            }
+        });
+    }
+
     // TODO: 实验性功能，替换 HTML 文本中的语音控件版本，不涉及数据的变更
     replaceVoiceToVersion2();
     ensureVoiceBoxesDraggable();
@@ -977,6 +1156,10 @@ function enableSummerNote() {
  * @returns {any} 
  */
 function rightClick(e) {
+    // 保存右键点击位置
+    lastRightClickX = e.clientX;
+    lastRightClickY = e.clientY;
+    
     // isShowAir = false;
     var testDiv = getSelectedRange();
     let childrenLength = $(testDiv).children().length
@@ -1005,7 +1188,14 @@ function rightClick(e) {
         $('#summernote').summernote('airPopover.hide');
         setSelectRange($(e.target).closest('.voiceBox')[0]);
     } else if (voiceLength == childrenLength && childrenLength != 0) {
-        recordActiveVoice()
+        // selection中只有语音块，但右键点击位置不在语音块上，说明是旧的selection，需要清除
+        if ($(e.target).closest('.voiceBox').length == 0) {
+            // 点击的不是语音块，清除旧选区，让getSelectedRange()返回空内容
+            window.getSelection().removeAllRanges();
+        } else {
+            // 点击的确实是语音块，记录它
+            recordActiveVoice()
+        }
     }
     let info = isRangeVoice()
     webobj.jsCallPopupMenu(info.flag, info.info);
@@ -1013,6 +1203,69 @@ function rightClick(e) {
     // e.preventDefault()
 }
 
+/**
+ * 接收QML传来的菜单位置，计算并显示工具栏
+ */
+function setMenuPosition(menuX, menuY, menuWidth, menuHeight) {
+    console.log("收到菜单位置: x=" + menuX + ", y=" + menuY + ", w=" + menuWidth + ", h=" + menuHeight);
+    console.log("右键点击位置: x=" + lastRightClickX + ", y=" + lastRightClickY);
+    
+    var winWidth = $(window).width();
+    var winHeight = $(window).height();
+    var scrollLeft = $(document).scrollLeft();
+    var scrollTop = $(document).scrollTop();
+    
+    // 获取工具栏实际尺寸
+    var $airPopover = $('.note-air-popover');
+    var toolbarHeight = $airPopover.outerHeight() || 44;
+    var toolbarWidth = $airPopover.outerWidth() || 385;
+    
+    var spacing = 10;  // 固定间距
+    
+    console.log("工具栏尺寸: w=" + toolbarWidth + ", h=" + toolbarHeight);
+    console.log("窗口尺寸: w=" + winWidth + ", h=" + winHeight);
+    
+    // 计算菜单到顶部和底部的距离
+    var menuTopDistance = menuY;
+    var menuBottomDistance = winHeight - (menuY + menuHeight);
+    
+    console.log("菜单顶部距离: " + menuTopDistance + ", 底部距离: " + menuBottomDistance);
+    
+    // 计算工具栏X坐标（以点击位置为基准，确保不超出边界）
+    var toolbarX = lastRightClickX;
+    if (toolbarX + toolbarWidth > winWidth) {
+        toolbarX = winWidth - toolbarWidth - 10;
+    }
+    if (toolbarX < 10) {
+        toolbarX = 10;
+    }
+    
+    // 计算工具栏Y坐标
+    var toolbarY;
+    if (menuTopDistance >= toolbarHeight + spacing) {
+        // 菜单上方空间足够，放在上方
+        toolbarY = menuY - toolbarHeight - spacing;
+        console.log("工具栏放在菜单上方");
+    } else if (menuBottomDistance >= toolbarHeight + spacing) {
+        // 菜单下方空间足够，放在下方
+        toolbarY = menuY + menuHeight + spacing;
+        console.log("工具栏放在菜单下方");
+    } else {
+        // 上下都不够，放在空间更大的一侧
+        if (menuTopDistance > menuBottomDistance) {
+            toolbarY = 10;  // 贴顶
+            console.log("工具栏贴顶");
+        } else {
+            toolbarY = winHeight - toolbarHeight - 10;  // 贴底
+            console.log("工具栏贴底");
+        }
+    }
+    
+    console.log("最终工具栏位置: x=" + toolbarX + ", y=" + toolbarY);
+    
+    // 显示工具栏（转换为文档坐标）
+    showRightMenu(toolbarX + scrollLeft, toolbarY + scrollTop);
+}
 
 /**
  * 设置活动色
@@ -1021,6 +1274,9 @@ function rightClick(e) {
  * @returns {any}
  */
 function setVoiceButColor(color, shdow) {
+    // 判断是否为禁用状态（颜色和阴影都是禁用色）
+    var isDisabled = (color === global_disableColor && shdow === global_disableColor);
+    
     $("#style").html(`
     :root {
         --highlightColor: ${color};
@@ -1028,7 +1284,8 @@ function setVoiceButColor(color, shdow) {
 
     .voiceBox .voiceBtn {
         background-color: ${color};
-        box-shadow: 0px 4px 6px 0px ${shdow}80; 
+        box-shadow: 0px 4px 6px 0px ${shdow}80;
+        ${isDisabled ? 'filter: grayscale(100%) opacity(0.5);' : ''}
     } 
     ::selection {
         background: ${color}!important;
@@ -1049,8 +1306,14 @@ function setVoiceButColor(color, shdow) {
         background: ${color}80!important;
     }
 
-    .li:active .translateText::selection {
-        background-color: none !important;
+    .li .translateText::selection {
+        background: ${color}40 !important;
+        color: inherit;
+    }
+    
+    .li.active .translateText::selection {
+        background: ${color}60 !important;
+        color: inherit;
     }    
     `)
 }
@@ -1069,7 +1332,12 @@ function changeColor(flag, activeColor, disableColor, backgroundColor) {
     global_activeColor = activeColor
     global_disableColor = disableColor
     global_themeColor = backgroundColor
-    setVoiceButColor(global_activeColor, global_disableColor)
+    // 根据录音状态设置按钮颜色：录音时置灰，非录音时正常
+    if (global_isRecording) {
+        setVoiceButColor(global_disableColor, global_disableColor)
+    } else {
+        setVoiceButColor(global_activeColor, global_disableColor)
+    }
 
     $('.dropdown-fontsize>li>a').hover(function (e) {
         $(this).css('background-color', activeColor);
@@ -1209,8 +1477,22 @@ function initVoiceDragAndDrop() {
  * @returns {any}
  */
 async function insertImg(urlStr) {
-    urlStr.forEach((item, index) => {
-        $("#summernote").summernote('insertImage', item, 'img');
+    // 后端已发送相对路径 images/xxx，显示时转换为绝对路径，保存时保持相对路径
+    urlStr.forEach((item) => {
+        var relPath = ('' + item).replace(/\\/g, '/');
+        // 显示时使用绝对路径
+        var displayUrl = relPath;
+        if (globalAppDataBase && relPath.indexOf('images/') === 0) {
+            try {
+                displayUrl = new URL(relPath, globalAppDataBase).href;
+            } catch (e) {
+                displayUrl = relPath;
+            }
+        }
+        $("#summernote").summernote('insertImage', displayUrl, function ($image) {
+            // 保存相对路径到 data 属性，保存 HTML 时使用
+            $image.attr('data-rel-path', relPath);
+        });
     })
 }
 
@@ -1218,6 +1500,13 @@ async function insertImg(urlStr) {
  * trigger play/pause voice when key space / return / enter down
  */
 function triggerPlayPauseVoice(event) {
+    // 录音时禁止播放语音
+    if (global_isRecording) {
+        console.log("Cannot play voice while recording (triggered by keyboard)");
+        event.preventDefault();  // 阻止Enter/Space键的默认行为，防止删除选中内容
+        return false;
+    }
+    
     var currentLi = $('.li.active');
     if (currentLi.length > 0) {
         event.preventDefault();
@@ -1296,6 +1585,17 @@ document.onkeydown = function (event) {
 
     } else if (window.event.keyCode == 8) {
         // backspace
+        // 检查是否选中了语音块
+        var testDiv = getSelectedRange();
+        if ($(testDiv).find('.voiceBox').length == $(testDiv).children().length && $(testDiv).children().length != 0) {
+            if (activePlayback && activePlayback.hasClass('play')) {
+                console.log("Cannot delete voice while playing");
+                return false;
+            }
+            deleteSelection();
+            return false;
+        }
+        
         if (getSelectedRange().innerHTML == document.querySelector('.note-editable').innerHTML) {
             $('.note-editable').html('<p><br></p>')
         }
@@ -1310,6 +1610,34 @@ document.onkeydown = function (event) {
         if (selectionObj.type != 'Caret') {
             return
         }
+        
+        // 检查光标前面是否是语音块（从普通文本向语音块删除）
+        if (selectionObj.anchorOffset === 0 && focusDom.nodeType === 3) {
+            var $parent = $(focusDom).parent();
+            var $prevElement = $parent.prev();
+            
+            // 如果前一个元素是语音块
+            if ($prevElement.hasClass('voiceBox')) {
+                if (activePlayback && activePlayback.hasClass('play')) {
+                    console.log("Cannot delete voice while playing");
+                    return false;
+                }
+                setSelectRange($prevElement[0]);
+                deleteSelection();
+                return false;
+            }
+            
+            // 如果父元素的前一个元素是语音块
+            if ($parent.is('p') && $parent.prev().hasClass('voiceBox')) {
+                if (activePlayback && activePlayback.hasClass('play')) {
+                    console.log("Cannot delete voice while playing");
+                    return false;
+                }
+                setSelectRange($parent.prev()[0]);
+                deleteSelection();
+                return false;
+            }
+        }
         if ($(focusDom).closest('span').length
             && $(focusDom).closest('span').html() !== '<br>'
             && selectionObj.extentOffset == 0) {
@@ -1338,6 +1666,19 @@ document.onkeydown = function (event) {
         }
     } else if (window.event.keyCode == 46) {
         // delete
+        // 检查是否选中了语音块
+        var testDiv = getSelectedRange();
+        if ($(testDiv).find('.voiceBox').length == $(testDiv).children().length && $(testDiv).children().length != 0) {
+            // 选中的是语音块，检查是否有语音正在播放
+            if (activePlayback && activePlayback.hasClass('play')) {
+                console.log("Cannot delete voice while playing");
+                return false;
+            }
+            // 没有播放，允许删除
+            deleteSelection();
+            return false;
+        }
+        
         var selectionObj = window.getSelection();
         let focusDom = selectionObj.extentNode
         let domList = $(focusDom).parents()
@@ -1705,15 +2046,24 @@ function updateProgressBar(value) {
     }
 
     if (null !== activePlayback && activePlayback.hasClass('now')) {
+        if (!$.contains(document.documentElement, activePlayback[0])) {
+            activePlayback = null;
+            return;
+        }
         var progressBar = activePlayback.find('.progressBar').get(0);
+        if (!progressBar) {
+            return;
+        }
         // 按秒进位
         progressBar.value = (value / 1000) * 1000;
         updateProgressBarValue(progressBar, progressBar.value);
 
         // 同步更新浮动窗口进度条
         var airProgressBar = airVoicePlayback.find('.progressBar').get(0);
-        airProgressBar.value = progressBar.value;
-        updateProgressBarValue(airProgressBar, progressBar.value);
+        if (airProgressBar) {
+            airProgressBar.value = progressBar.value;
+            updateProgressBarValue(airProgressBar, progressBar.value);
+        }
     }
 }
 
