@@ -4,7 +4,7 @@
 <context>
     <name>AppMain</name>
     <message>
-        <location filename="../src/common/vlcplayer.cpp" line="85"/>
+        <location filename="../src/common/vlcplayer.cpp" line="87"/>
         <source>Voice Notes</source>
         <translation>Notatki głosowe</translation>
     </message>
@@ -12,7 +12,7 @@
 <context>
     <name>DefaultName</name>
     <message>
-        <location filename="../src/db/vnotefolderoper.cpp" line="226"/>
+        <location filename="../src/db/vnotefolderoper.cpp" line="249"/>
         <source>Notebook</source>
         <translation>Notatnik</translation>
     </message>
@@ -22,9 +22,9 @@
         <translation>Głos</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="214"/>
+        <location filename="../src/db/vnoteitemoper.cpp" line="226"/>
         <source>Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Tekst</translation>
     </message>
 </context>
 <context>
@@ -42,7 +42,7 @@
     <message>
         <location filename="../src/gui/mainwindow/FolderListView.qml" line="545"/>
         <source>New Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Nowa notatka</translation>
     </message>
 </context>
 <context>
@@ -50,7 +50,7 @@
     <message>
         <location filename="../src/gui/mainwindow/InitialInterface.qml" line="66"/>
         <source>After creating a new notepad, you can start recording voice and text</source>
-        <translation type="unfinished"></translation>
+        <translation>Po utworzeniu nowej notatki możesz rozpocząć nagrywanie głosu i tekstu</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/InitialInterface.qml" line="73"/>
@@ -61,44 +61,42 @@
 <context>
     <name>ItemListView</name>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="78"/>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="80"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
         <source>move </source>
-        <translation type="unfinished"></translation>
+        <translation>przenieś </translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="78"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
         <source> notes to :</source>
-        <translation type="unfinished"></translation>
+        <translation> notatki do :</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="80"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="81"/>
         <source> note to :</source>
-        <translation type="unfinished"></translation>
+        <translation> notatke do :</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="163"/>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="190"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="160"/>
         <source>Save As</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz jako</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="228"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="279"/>
         <source>No search results</source>
         <translation type="unfinished">Brak wyników wyszukiwania</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="244"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
         <source>Unpin</source>
-        <translation type="unfinished"></translation>
+        <translation>Opuść</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="244"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
         <source>Sticky on Top</source>
         <translation type="unfinished">Przypnij na górze</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="690"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="752"/>
         <source>Sticky Notes</source>
         <translation type="unfinished">Przyczepione notatki</translation>
     </message>
@@ -106,12 +104,12 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/gui/mainwindow/MainWindow.qml" line="381"/>
+        <location filename="../src/gui/mainwindow/MainWindow.qml" line="370"/>
         <source>Create Notebook</source>
         <translation type="unfinished">Utwórz notatnik</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/MainWindow.qml" line="534"/>
+        <location filename="../src/gui/mainwindow/MainWindow.qml" line="523"/>
         <source>Search</source>
         <translation type="unfinished">Szukaj</translation>
     </message>
@@ -121,17 +119,17 @@
     <message>
         <location filename="../src/gui/dialog/MoveDialog.qml" line="24"/>
         <source>Move Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Przenieś notatkę</translation>
     </message>
     <message>
-        <location filename="../src/gui/dialog/MoveDialog.qml" line="127"/>
+        <location filename="../src/gui/dialog/MoveDialog.qml" line="136"/>
         <source>Cancel</source>
         <translation type="unfinished">Anuluj</translation>
     </message>
     <message>
-        <location filename="../src/gui/dialog/MoveDialog.qml" line="144"/>
+        <location filename="../src/gui/dialog/MoveDialog.qml" line="153"/>
         <source>Ok</source>
-        <translation type="unfinished"></translation>
+        <translation>OK</translation>
     </message>
 </context>
 <context>
@@ -139,7 +137,7 @@
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="37"/>
         <source>%1 note selected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 notatka wybrana</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="56"/>
@@ -149,12 +147,12 @@
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="69"/>
         <source>Save Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz notatkę</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="82"/>
         <source>Save Voice</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz głos</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="93"/>
@@ -165,90 +163,80 @@
 <context>
     <name>NoteDetailContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="68"/>
+        <location filename="../src/common/actionmanager.cpp" line="69"/>
         <source>Save as MP3</source>
         <translation>Zapisz jako MP3</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="69"/>
+        <location filename="../src/common/actionmanager.cpp" line="70"/>
         <source>Voice to Text</source>
         <translation>Głos na tekst</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="70"/>
-        <location filename="../src/common/actionmanager.cpp" line="78"/>
-        <location filename="../src/common/actionmanager.cpp" line="86"/>
+        <location filename="../src/common/actionmanager.cpp" line="71"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="71"/>
-        <location filename="../src/common/actionmanager.cpp" line="79"/>
-        <location filename="../src/common/actionmanager.cpp" line="87"/>
+        <location filename="../src/common/actionmanager.cpp" line="72"/>
         <source>Select all</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybierz wszystko</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="72"/>
-        <location filename="../src/common/actionmanager.cpp" line="80"/>
-        <location filename="../src/common/actionmanager.cpp" line="88"/>
+        <location filename="../src/common/actionmanager.cpp" line="73"/>
         <source>Copy</source>
         <translation>Kopiuj</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="73"/>
-        <location filename="../src/common/actionmanager.cpp" line="81"/>
-        <location filename="../src/common/actionmanager.cpp" line="89"/>
+        <location filename="../src/common/actionmanager.cpp" line="74"/>
         <source>Cut</source>
         <translation>Wytnij</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="74"/>
-        <location filename="../src/common/actionmanager.cpp" line="82"/>
-        <location filename="../src/common/actionmanager.cpp" line="90"/>
+        <location filename="../src/common/actionmanager.cpp" line="75"/>
         <source>Paste</source>
         <translation>Wklej</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="77"/>
+        <location filename="../src/common/actionmanager.cpp" line="78"/>
         <source>View</source>
         <translation>Wyświetl</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="83"/>
+        <location filename="../src/common/actionmanager.cpp" line="84"/>
         <source>Save as</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="92"/>
-        <source>Text to Speech</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz jako</translation>
     </message>
     <message>
         <location filename="../src/common/actionmanager.cpp" line="93"/>
-        <source>Stop reading</source>
-        <translation type="unfinished"></translation>
+        <source>Text to Speech</source>
+        <translation>Tekst do mowy</translation>
     </message>
     <message>
         <location filename="../src/common/actionmanager.cpp" line="94"/>
+        <source>Stop reading</source>
+        <translation>Zatrzymaj odczyt</translation>
+    </message>
+    <message>
+        <location filename="../src/common/actionmanager.cpp" line="95"/>
         <source>Speech to Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Mowa do tekstu</translation>
     </message>
 </context>
 <context>
     <name>NotebookContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="46"/>
+        <location filename="../src/common/actionmanager.cpp" line="47"/>
         <source>Rename</source>
         <translation>Zmień nazwę</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="47"/>
+        <location filename="../src/common/actionmanager.cpp" line="48"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="48"/>
+        <location filename="../src/common/actionmanager.cpp" line="49"/>
         <source>New note</source>
         <translation type="unfinished">Nowa notatka</translation>
     </message>
@@ -256,47 +244,47 @@
 <context>
     <name>NotesContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="62"/>
+        <location filename="../src/common/actionmanager.cpp" line="63"/>
         <source>Save as HTML</source>
         <translation>Zapisz jako HTML</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="63"/>
+        <location filename="../src/common/actionmanager.cpp" line="64"/>
         <source>Save as TXT</source>
         <translation>Zapisz jako TXT</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="56"/>
+        <location filename="../src/common/actionmanager.cpp" line="57"/>
         <source>Save note</source>
         <translation>Zapisz notatkę</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="51"/>
+        <location filename="../src/common/actionmanager.cpp" line="52"/>
         <source>Rename</source>
         <translation>Zmień nazwę</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="53"/>
+        <location filename="../src/common/actionmanager.cpp" line="54"/>
         <source>Move</source>
         <translation>Przenieś</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="54"/>
+        <location filename="../src/common/actionmanager.cpp" line="55"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="57"/>
+        <location filename="../src/common/actionmanager.cpp" line="58"/>
         <source>Save voice recording</source>
         <translation>Zapisz nagranie głosowe</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="59"/>
+        <location filename="../src/common/actionmanager.cpp" line="60"/>
         <source>New note</source>
         <translation>Nowa notatka</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="52"/>
+        <location filename="../src/common/actionmanager.cpp" line="53"/>
         <source>Sticky on Top</source>
         <translation>Przypnij na górze</translation>
     </message>
@@ -304,25 +292,24 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="230"/>
-        <source>Please install &apos;UOS AI&apos; from the App Store before using</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="261"/>
+        <source>Please install 'UOS AI' from the App Store before using</source>
+        <translation>Proszę zainstalować 'UOS AI' z Magazynu aplikacji przed użyciem</translation>
     </message>
     <message>
-        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="232"/>
+        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="263"/>
         <source>No audio input device detected. Please check and try again</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie znaleziono urządzenia wejściowego audio. Sprawdź i spróbuj ponownie</translation>
     </message>
     <message>
-        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="234"/>
+        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="265"/>
         <source>No audio output device detected. Please check and try again</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie znaleziono urządzenia wyjściowego audio. Sprawdź i spróbuj ponownie</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="56"/>
-        <location filename="../src/main.cpp" line="57"/>
+        <location filename="../src/main.cpp" line="99"/>
         <source>deepin-voice-note</source>
-        <translation type="unfinished"></translation>
+        <translation>deepin-voice-note</translation>
     </message>
 </context>
 <context>
@@ -374,120 +361,120 @@
 <context>
     <name>Shortcuts</name>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="742"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="804"/>
         <source>New notebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Nowy zeszyt</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="743"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="805"/>
         <source>Rename notebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Zmień nazwę zeszytu</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="744"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="806"/>
         <source>Delete notebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Usunąć zeszyt</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="766"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="828"/>
         <source>New note</source>
         <translation type="unfinished">Nowa notatka</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="767"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="829"/>
         <source>Rename note</source>
-        <translation type="unfinished"></translation>
+        <translation>Zmień nazwę notatki</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="768"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="830"/>
         <source>Delete note</source>
-        <translation type="unfinished"></translation>
+        <translation>Usunąć notatkę</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="769"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="831"/>
         <source>Play/Pause</source>
-        <translation type="unfinished"></translation>
+        <translation>Odtwórz/Wstrzymaj</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="770"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="832"/>
         <source>Record voice</source>
-        <translation type="unfinished"></translation>
+        <translation>Nagraj głos</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="771"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="833"/>
         <source>Save note</source>
         <translation type="unfinished">Zapisz notatkę</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="772"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="834"/>
         <source>Save recordings</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz nagrania</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="792"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="854"/>
         <source>Select all</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaznacz wszystko</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="793"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="855"/>
         <source>Copy</source>
         <translation type="unfinished">Kopiuj</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="794"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="856"/>
         <source>Cut</source>
         <translation type="unfinished">Wytnij</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="795"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="857"/>
         <source>Paste</source>
         <translation type="unfinished">Wklej</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="796"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="858"/>
         <source>Undo</source>
-        <translation type="unfinished"></translation>
+        <translation>Cofnij</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="797"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="859"/>
         <source>Redo</source>
-        <translation type="unfinished"></translation>
+        <translation>Powtórz</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="798"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="860"/>
         <source>Delete</source>
         <translation type="unfinished">Usuń</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="821"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="883"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Pomoc</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="822"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="884"/>
         <source>Display shortcuts</source>
-        <translation type="unfinished"></translation>
+        <translation>Pokaż skróty</translation>
     </message>
 </context>
 <context>
     <name>ShortcutsGroups</name>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="748"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="810"/>
         <source>Notebooks</source>
-        <translation type="unfinished"></translation>
+        <translation>Zeszyty</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="776"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="838"/>
         <source>Notes</source>
-        <translation type="unfinished"></translation>
+        <translation>Notatki</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="802"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="864"/>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Edytuj</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="826"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="888"/>
         <source>Settings</source>
         <translation type="unfinished">Ustawienia</translation>
     </message>
@@ -502,17 +489,17 @@
     <message>
         <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="30"/>
         <source>Privacy Policy</source>
-        <translation type="unfinished"></translation>
+        <translation>Polityka prywatności</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="53"/>
         <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice Notes to lekki narzędzie do tworzenia notatek tekstowych i nagraniń głosowych.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="55"/>
         <source>Voice Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Notatka głosowa</translation>
     </message>
 </context>
 <context>
@@ -526,27 +513,110 @@
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../src/common/utils.cpp" line="42"/>
+        <location filename="../src/common/utils.cpp" line="46"/>
         <source>1 min ago</source>
         <translation>1 min temu</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="44"/>
+        <location filename="../src/common/utils.cpp" line="48"/>
         <source>%1 mins ago</source>
         <translation>%1 min temu</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="50"/>
+        <location filename="../src/common/utils.cpp" line="56"/>
         <source>Yesterday</source>
         <translation>Wczoraj</translation>
     </message>
+    <message>
+        <location filename="../tests/src/common/ut_utils.cpp" line="33"/>
+        <source>2 mins ago</source>
+        <translation>2 minuty temu</translation>
+    </message>
+</context>
+<context>
+    <name>VNoteMessageDialog</name>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="28"/>
+        <source>OK</source>
+        <comment>button</comment>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="39"/>
+        <source>Are you sure you want to delete this notebook?
+All notes in it will be deleted</source>
+        <translation>Czy na pewno chcesz usunąć ten zeszyt?
+Wszystkie notatki w nim będą usunięte</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
+        <source>Do you want to stop the current recording?</source>
+        <translation type="unfinished">Czy chcesz zatrzymać bieżące nagrywanie?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="52"/>
+        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
+        <translation type="unfinished">Nie można przekonwertować tej notatki głosowej, ponieważ notatki powyżej 20 minut nie są obecnie obsługiwane.</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
+        <source>Converting a voice note now. Do you want to stop it?</source>
+        <translation type="unfinished">Konwertowanie notatki głosowej. Czy chcesz zatrzymać?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="65"/>
+        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
+        <translation type="unfinished">Niski poziom głośności mikrofonu może skutkować złym nagraniem. Czy chcesz kontynuować?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
+        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
+        <translation type="unfinished">Przycięte nagrania i przekonwertowany tekst nie zostaną wklejone. Czy chcesz kontynuować?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="81"/>
+        <source>Are you sure you want to delete this note?</source>
+        <translation type="unfinished">Czy na pewno chcesz usunąć tę notatkę?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="87"/>
+        <source>Are you sure you want to delete the selected %1 notes?</source>
+        <translation type="unfinished">Czy na pewno chcesz usunąć %1 notatek?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation type="unfinished">Anuluj</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="98"/>
+        <source>Confirm</source>
+        <comment>button</comment>
+        <translation type="unfinished">Potwierdź</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="106"/>
+        <source>Save failed</source>
+        <translation type="unfinished">Nie udało się zapisać</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="111"/>
+        <source>You do not have permission to save files there</source>
+        <translation type="unfinished">Nie posiadasz uprawnień do zapisu plików tutaj</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="116"/>
+        <source>The voice note has been deleted</source>
+        <translation type="unfinished">Notatka głosowa została usunięta</translation>
+    </message>
 </context>
 <context>
     <name>VNoteMessageDialogHandler</name>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="97"/>
         <source>Are you sure you want to delete this notebook?</source>
-        <translation type="unfinished"></translation>
+        <translation>Czy na pewno chcesz usunąć ten zeszyt?</translation>
     </message>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="99"/>
@@ -601,12 +671,12 @@
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="129"/>
         <source>The voice conversion failed due to the poor network connection, please have a check</source>
-        <translation type="unfinished"></translation>
+        <translation>Konwersja głosu do tekstu zakończyła się niepowodzeniem z powodu słabej połączenia sieciowego, proszę sprawdzić</translation>
     </message>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="141"/>
         <source>All notes in it will be deleted</source>
-        <translation type="unfinished"></translation>
+        <translation>Wszystkie notatki w nim zostaną usunięte</translation>
     </message>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="154"/>
@@ -630,9 +700,9 @@
 <context>
     <name>WebEngineHandler</name>
     <message>
-        <location filename="../src/handler/web_engine_handler.cpp" line="483"/>
+        <location filename="../src/handler/web_engine_handler.cpp" line="647"/>
         <source>save as MP3</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz jako MP3</translation>
     </message>
 </context>
 <context>
@@ -640,95 +710,95 @@
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="60"/>
         <source>Create Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Utwórz notatkę</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
         <source>Start recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozpocznij nagrywanie</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
         <source>No recording device detected</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie znaleziono urządzenia do nagrywania</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="119"/>
         <source>Insert picture</source>
-        <translation type="unfinished"></translation>
+        <translation>Wstaw obraz</translation>
     </message>
 </context>
 <context>
     <name>web</name>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="131"/>
+        <location filename="../src/common/jscontent.cpp" line="146"/>
         <source>Font</source>
         <translation>Czcionka</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="132"/>
+        <location filename="../src/common/jscontent.cpp" line="147"/>
         <source>Font size</source>
         <translation>Rozmiar czcionki</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="133"/>
+        <location filename="../src/common/jscontent.cpp" line="148"/>
         <source>Font color</source>
         <translation>Kolor czcionki</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="134"/>
+        <location filename="../src/common/jscontent.cpp" line="149"/>
         <source>Text highlight color</source>
         <translation>Kolor wyróżnionego tekstu</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="135"/>
+        <location filename="../src/common/jscontent.cpp" line="150"/>
         <source>Bold</source>
         <translation>Pogrubienie</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="136"/>
+        <location filename="../src/common/jscontent.cpp" line="151"/>
         <source>Italic</source>
         <translation>Kursywa</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="137"/>
+        <location filename="../src/common/jscontent.cpp" line="152"/>
         <source>Underline</source>
         <translation>Podkreślenie</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="138"/>
+        <location filename="../src/common/jscontent.cpp" line="153"/>
         <source>Strikethrough</source>
         <translation>Przekreślenie</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="139"/>
+        <location filename="../src/common/jscontent.cpp" line="154"/>
         <source>Bullets</source>
         <translation>Punktory</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="140"/>
+        <location filename="../src/common/jscontent.cpp" line="155"/>
         <source>Numbering</source>
         <translation>Numerowanie</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="141"/>
+        <location filename="../src/common/jscontent.cpp" line="156"/>
         <source>More colors</source>
         <translation>Więcej kolorów</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="142"/>
+        <location filename="../src/common/jscontent.cpp" line="157"/>
         <source>Recent</source>
         <translation>Ostatnie</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="156"/>
+        <location filename="../src/common/jscontent.cpp" line="173"/>
         <source>Voice To Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Głos do tekstu</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="157"/>
+        <location filename="../src/common/jscontent.cpp" line="174"/>
         <source>Converting voice to text</source>
-        <translation type="unfinished"></translation>
+        <translation>Konwersja głosu do tekstu</translation>
     </message>
 </context>
 </TS>
